Test coverage report: markupmirror.markup.textile_

# markupmirror.markup.textile_: 18 total statements, 100.0% covered

Generated: Wed 2012-04-11 05:19 CDT

Source file: /home/buechler/Sites/django-markupmirror/markupmirror/markup/textile_.py

Stats: 11 executed, 0 missed, 7 excluded, 13 ignored

1. `from django.utils.translation import ugettext_lazy as _`
2. ``
3. `from markupmirror import settings`
4. `from markupmirror.markup.base import BaseMarkup`
5. `from markupmirror.markup.base import register_markup`
6. ``
7. ``
8. `class TextileMarkup(BaseMarkup):`
9. `"""Markup transformer for Textile content.`
10. ``
11. `"""`
12. `codemirror_mode = ''`
13. `title = _(u"Textile")`
14. ``
15. `def __init__(self):`
16. `self.textile_settings = settings.TEXTILE_SETTINGS`
17. `self.textile = textile`
18. ``
19. `def convert(self, markup):`
20. `return self.textile(markup, **self.textile_settings)`
21. ``
22. ``
23. `# Only register if textile is installed`
24. `try:`
25. `from textile import textile`
26. `register_markup(TextileMarkup)`
27. `except ImportError:`
28. `pass`
29. ``
30. ``
31. `__all__ = ('TextileMarkup',)`